using System.Collections;
using System.Collections.Generic;
using Unity.Burst.CompilerServices;
using UnityEngine;

/// <summary>
/// Handles collision details by interacting with the DataVisualizer.
/// Responsible for showing and removing details on demand.
/// </summary>
public class CollisionDetailHandler : MonoBehaviour
{
    /// <summary>
    /// Reference to the DataVisualizer component.
    /// </summary>
    private DataVisualizer dataVisualizer;

    /// <summary>
    /// Unity Start method, called before the first frame update.
    /// Initializes the reference to the DataVisualizer.
    /// </summary>
    void Start()
    {
        dataVisualizer = GameObject.Find("DataVisualizer").GetComponent<DataVisualizer>();
    }

    /// <summary>
    /// Shows detailed information at the object's position.
    /// </summary>
    public void ShowDetails()
    {
        dataVisualizer.ShowDetailsOnDemand(
            transform.parent.name,
            transform.position + transform.forward * transform.localScale.z * 1.03f * dataVisualizer.GetGlobeScale().z
        );
    }

    /// <summary>
    /// Removes any displayed detailed information.
    /// </summary>
    public void RemoveDetails()
    {
        dataVisualizer.RemoveDetailsOnDemand();
    }
}